@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,12 +21,33 @@
 #ifndef GDM_SERVER_H
 #define GDM_SERVER_H
 
-#include "gdm.h"
+#include "display.h"
+
+typedef struct _GdmXserver GdmXserver;
+
+struct _GdmXserver
+{
+	char *id;
+	char *name;
+	char *command;
+	gboolean flexible;
+	gboolean choosable; /* not implemented yet */
+	gboolean chooser; /* instead of greeter, run chooser */
+	gboolean handled;
+	int priority;
+};
+
+/* These are the servstat values, also used as server
+ * process exit codes */
+#define SERVER_TIMEOUT 2	/* Server didn't start */
+#define SERVER_DEAD 250		/* Server stopped */
+#define SERVER_PENDING 251	/* Server started but not ready for connections yet */
+#define SERVER_RUNNING 252	/* Server running and ready for connections */
+#define SERVER_ABORT 253	/* Server failed badly. Suspending display. */
 
 /* Wipe cookie files */
 void		gdm_server_wipe_cookies	(GdmDisplay *disp);
 
-/* Wipe X server's butt */
 void		gdm_server_whack_lockfile (GdmDisplay *disp);
 
 gboolean	gdm_server_start	(GdmDisplay *d,
@@ -34,14 +57,14 @@ gboolean	gdm_server_start	(GdmDisplay *d,
 					 int flexi_retries);
 void		gdm_server_stop		(GdmDisplay *d);
 gboolean	gdm_server_reinit	(GdmDisplay *d);
-GdmDisplay *	gdm_server_alloc	(gint id,
-					 const gchar *command);
 void		gdm_server_whack_clients (Display *dsp);
 void		gdm_server_checklog	(GdmDisplay *disp);
 
-char **		gdm_server_resolve_command_line (GdmDisplay *disp,
+gboolean	gdm_server_resolve_command_line (GdmDisplay *disp,
 						 gboolean resolve_flags,
-						 const char *vtarg);
+						 const char *vtarg,
+                                                 int        *argc,
+                                                 char     ***argv);
 GdmXserver *	gdm_server_resolve	(GdmDisplay *disp);
 
 
